summaryrefslogtreecommitdiff
path: root/indra/newview/llstartup.cpp
diff options
context:
space:
mode:
authorSteven Bennetts <steve@lindenlab.com>2008-04-23 01:04:01 +0000
committerSteven Bennetts <steve@lindenlab.com>2008-04-23 01:04:01 +0000
commit39018947081772bf7226d757c647520c54b18fd2 (patch)
tree74b00b3006878d7e576b84cb3240d98c22d67db9 /indra/newview/llstartup.cpp
parentc01edec021194bacb86dc9a3f5a3cc655a8cb15f (diff)
QAR-488 Viewer 1.20 RC 2
merge Branch_1-20-Viewer -r 84760 : 85100 -> release
Diffstat (limited to 'indra/newview/llstartup.cpp')
-rw-r--r--indra/newview/llstartup.cpp9
1 files changed, 6 insertions, 3 deletions
diff --git a/indra/newview/llstartup.cpp b/indra/newview/llstartup.cpp
index 6cd4d90e5f..139ab8f1aa 100644
--- a/indra/newview/llstartup.cpp
+++ b/indra/newview/llstartup.cpp
@@ -773,9 +773,12 @@ BOOL idle_startup()
gDirUtilp->setLindenUserDir(firstname.c_str(), lastname.c_str());
LLFile::mkdir(gDirUtilp->getLindenUserDir().c_str());
- // Set UserSettingsFile to the default value.
- gSavedSettings.setString("UserSettingsFile",
- gDirUtilp->getExpandedFilename(LL_PATH_PER_SL_ACCOUNT, DEFAULT_SETTINGS_FILE));
+ // Set PerAccountSettingsFile to the default value.
+ gSavedSettings.setString("PerAccountSettingsFile",
+ gDirUtilp->getExpandedFilename(LL_PATH_PER_SL_ACCOUNT,
+ LLAppViewer::instance()->getSettingsFileName("PerAccount")
+ )
+ );
// Overwrite default user settings with user settings
LLAppViewer::instance()->loadSettingsFromDirectory(LL_PATH_PER_SL_ACCOUNT);